@@ -2,7 +2,7 @@
 PRISM_resamp <- function(PRISM.fit, Y, A, X, Xtest=NULL, family="gaussian",
                        filter="filter_glmnet", ple=NULL, submod=NULL, param=NULL,
                        meta = "X-learner",
-                       pool = "no", delta = ">0", 
+                       pool = "no", delta = ">0", propensity = FALSE,
                        alpha_ovrl=0.05, alpha_s = 0.05,
                        filter.hyper=NULL, ple.hyper=NULL, submod.hyper = NULL,
                        param.hyper = NULL, verbose=TRUE,
@@ -77,7 +77,7 @@ PRISM_resamp <- function(PRISM.fit, Y, A, X, Xtest=NULL, family="gaussian",
     res.R <- tryCatch(PRISM_train(Y=Y.R, A=A.R, X=X.R, Xtest=Xtest.R, family=family, 
                         filter=filter, ple=ple, submod = submod, param=param,
                         meta=meta, 
-                        pool = pool, delta = delta, 
+                        pool = pool, delta = delta, propensity = propensity, 
                         alpha_ovrl = alpha_ovrl, alpha_s = alpha_s,
                         filter.hyper = filter.hyper, ple.hyper = ple.hyper,
                         submod.hyper = submod.hyper,
