@@ -10,14 +10,30 @@
 #' @param ... Additional arguments (currently ignored).
 #' @return Plot (ggplot2) object
 #' @export
+#' @examples
+#' library(StratifiedMedicine)
+#' ## Continuous ##
+#' dat_ctns = generate_subgrp_data(family="gaussian")
+#' Y = dat_ctns$Y
+#' X = dat_ctns$X
+#' A = dat_ctns$A
+#'
+#' mod1 = filter_train(Y=Y, A=A, X=X)
+#' plot_importance(mod1)
 
 plot_importance <- function(object, top_n=NULL, ...) {
   
-  if (object$filter=="filter_glmnet") { 
-    plt.out <- plot_vimp_glmnet(object$filter.mod)
+  if (class(object)=="filter_train") {
+    filter.mod <- object$mod
   }
-  if (object$filter=="filter_ranger") {
-    plt.out <- plot_vimp_ranger(object$filter.mod, top_n=top_n)
+  if (class(object)=="PRISM") {
+    filter.mod <- object$filter.mod
+  }
+  if (object$filter=="filter_glmnet" | object$filter=="glmnet") { 
+    plt.out <- plot_vimp_glmnet(filter.mod)
+  }
+  if (object$filter=="filter_ranger" | object$filter=="ranger") {
+    plt.out <- plot_vimp_ranger(filter.mod, top_n=top_n)
   }
   return(plt.out)
 }
\ No newline at end of file
